@@ -11,20 +11,21 @@ _logger = _logging.getLogger(__name__)
 class Dictionary:
     """Dictionary."""
 
-    def __init__(self, path: str) -> None:
-        """__init__.
+    def __init__(self, unused_path: str) -> None:
+        """Init.
 
-        :param path:
-        :type path: str
+        :param unused_path:
+        :type unused_path: str
         :rtype: None
         """
-        _logger.error("Please install pyyaml firstly!")
+        _logger.error("Please install pystardict firstly!")
 
-    def get(self, text: str) -> str:
-        """get.
+    @staticmethod
+    def get(unused_text: str) -> str:
+        """Get.
 
-        :param text:
-        :type text: str
+        :param unused_text:
+        :type unused_text: str
         :rtype: str
         """
         return ""
