@@ -14,7 +14,7 @@ def run(args: Namespace) -> None:
     :type args: Namespace
     :rtype: None
     """
-    args = init(args)
+    init(args)
     if args.clipboard:
         from .gui import run as _run
 
